==> open-xchange-usm_7.2.2.orig.tar.bz2: open-xchange-usm-7.2.2/com.openexchange.usm.json/src/com/openexchange/usm/connector/sync/EmailSizeFilter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.connector.sync;

import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
import com.openexchange.usm.api.session.*;

public class EmailSizeFilter implements DataObjectFilter {

	private static final int DEFAULT_MAIL_SIZE = 1 << 20;

	private final long _originalSyncID;

	private final int _oneSyncSizeLimit;

	private final int _maxEmailSize;

	private int _size;
	
	private boolean _hadTooBigEmails;

	public EmailSizeFilter(long originalSyncID, int onesyncSizeLimit, int maxEmailSize) {
		_originalSyncID = originalSyncID;
		_oneSyncSizeLimit = onesyncSizeLimit;
		_maxEmailSize = maxEmailSize;
	}

	@Override
    public void initialize() {
		_size = 0;
		_hadTooBigEmails = false;
	}

	@Override
    public boolean accept(DataObject object) {
	    if(_maxEmailSize <= 0)
	        return true;
        boolean isTooBig = getMailSize(object) > _maxEmailSize;
        _hadTooBigEmails |= isTooBig;
        return !isTooBig;
    }

	@Override
    public boolean addOperationToResult(ChangeState action, DataObject object) {
		if (object == null)
			return false;
		if (!DefaultContentTypes.MAIL_ID.equals(object.getContentType().getID()))
			return false;
		switch (action) {
			case CREATED:
			case MODIFIED:
				int mailSize = getMailSize(object);
				if (_size > 0 && _size + mailSize >= _oneSyncSizeLimit)
					return false;
				_size += mailSize;
				return true;
			default:
				return true;
		}
	}

    private int getMailSize(DataObject object) {
		Object o = object.getFieldContent("size");
		return (o instanceof Number) ? ((Number) o).intValue() : DEFAULT_MAIL_SIZE;
	}

	@Override
    public long getOriginalSyncID() {
		return _originalSyncID;
	}
	
	public boolean hadTooBigEmails() {
	    return _hadTooBigEmails;
	}
}

==> open-xchange-usm_7.4.2.orig.tar.bz2: open-xchange-usm-7.4.2/com.openexchange.usm.json/src/com/openexchange/usm/connector/sync/EmailSizeFilter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.connector.sync;

import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
import com.openexchange.usm.api.session.ChangeState;
import com.openexchange.usm.api.session.DataObject;
import com.openexchange.usm.api.session.DataObjectFilter;

public class EmailSizeFilter implements DataObjectFilter {

    private static final int DEFAULT_MAIL_SIZE = 1 << 20;

    private final long _originalSyncID;

    private final int _oneSyncSizeLimit;

    private final int _maxEmailSize;

    private int _size;

    private boolean _hadTooBigEmails;

    public EmailSizeFilter(long originalSyncID, int onesyncSizeLimit, int maxEmailSize) {
        _originalSyncID = originalSyncID;
        _oneSyncSizeLimit = onesyncSizeLimit;
        _maxEmailSize = maxEmailSize;
    }

	@Override
    public void initialize() {
        _size = 0;
        _hadTooBigEmails = false;
    }

	@Override
    public boolean accept(DataObject object) {
	    if(_maxEmailSize <= 0)
	        return true;
        boolean isTooBig = getMailSize(object) > _maxEmailSize;
        _hadTooBigEmails |= isTooBig;
        return !isTooBig;
    }

	@Override
    public boolean addOperationToResult(ChangeState action, DataObject object) {
        if (object == null)
            return false;
        if (!DefaultContentTypes.MAIL_ID.equals(object.getContentType().getID()))
            return false;
        switch (action) {
        case CREATED:
        case MODIFIED:
            int mailSize = getMailSize(object);
            if (_size > 0 && _size + mailSize >= _oneSyncSizeLimit)
                return false;
            _size += mailSize;
            return true;
        default:
            return true;
        }
    }

    private int getMailSize(DataObject object) {
        Object o = object.getFieldContent("size");
        return (o instanceof Number) ? ((Number) o).intValue() : DEFAULT_MAIL_SIZE;
    }

	@Override
    public long getOriginalSyncID() {
        return _originalSyncID;
    }

    public boolean hadTooBigEmails() {
        return _hadTooBigEmails;
    }
}
